include <configuration.scad>;

separation = 40;
thickness = 6;

horn_thickness = 13;
horn_x = 8;

belt_width = 5;
belt_x = 5.6;
belt_z = 7;

module main_carriage() {
  // Timing belt (up and down).
  translate([-belt_x, 0, belt_z + belt_width/2]) %
    cube([1.7, 100, belt_width], center=true);
  translate([belt_x, 0, belt_z + belt_width/2]) %
    cube([1.7, 100, belt_width], center=true);
  difference() {
    union() {
      // Main body.
      translate([0, 4, thickness/2])
        cube([27, 40, thickness], center=true);
      // Ball joint mount horns.
      
      // Belt clamps.
      difference() {
        union() {
          translate([6.5, -2.5, horn_thickness/2+1])
            cube([14, 7, horn_thickness-2], center=true);
          translate([10.75, 2.5, horn_thickness/2+1])
            cube([5.5, 10, horn_thickness-2], center=true);
        }
        // Avoid touching diagonal push rods (carbon tube).
        translate([20, -10, 12.5]) rotate([35, 35, 30])
          cube([40, 40, 20], center=true);
      }
      for (y = [-12, 7]) {
        translate([1.25, y, horn_thickness/2+1])
          cube([7, 8, horn_thickness-2], center=true);
      }
    }
    // Screws for linear slider.
    for (x = [-10, 10]) {
      for (y = [-10, 10]) {
        translate([x, y, thickness]) #
          cylinder(r=m3_wide_radius, h=30, center=true, $fn=12);
      }
    }
    // Lock nuts for ball joints.
   // for (x = [-1, 1]) {
    //  scale([x, 1, 1]) intersection() {
     //   translate([horn_x, 16, horn_thickness/2]) rotate([90, 0, -90])
       //   cylinder(r1=m3_nut_radius, r2=m3_nut_radius+0.5, h=8,
        //           center=true, $fn=6);
     // }
    //}
  }
}

//START CARRIAGE UNIVERSAL JOINTS

width = 76;
height = 19;
carriage_hinge_offset=18;

offset = 25;
cutout = 13;
middle = 2*offset - width/2;

module parallel_joints(reinforced) {
  difference() {
    union() {
      intersection() {
        cube([width, 20, 8], center=true);
        rotate([0, 90, 0]) cylinder(r=5, h=width, center=true);
      }
      intersection() {
        translate([0, 18, 4]) rotate([45, 0, 0]) // 45 degree face
          cube([width, reinforced, reinforced], center=true);
        translate([0, 0, 20]) cube([width, 28, 40], center=true);
      }
      translate([0, 8, 0]) cube([width, 12, 8], center=true);
    }
    // Hole for universal joint screws
    rotate([0, 90, 0]) # cylinder(r=1.55, h=80, center=true, $fn=12);

// Cut out grooves for universal joints
    for (x = [-offset, offset]) {
      translate([x, 5.5, 0])
        cylinder(r=cutout/2, h=100, center=true, $fn=24);
      translate([x, -4.5, 0])
        cube([cutout, 20, 100], center=true);
      translate([x, 0, 0]) rotate([0, 90, 0]) rotate([0, 0, 30])
        cylinder(r=3.3, h=17, center=true, $fn=6);
    }
// Center cutout
    translate([0, 2, 0]) cylinder(r=middle, h=100, center=true);
    translate([0, -8, 0]) cube([2*middle, 20, 100], center=true);
  }
}

module carriage() {
	rotate([-90, 0, 180]) {
	translate([0, 0, -22]) 
  union() {
    difference() {
      union() {
        translate([0, -3, 0])
			 cube([76,6,height], center=true); // Main rectangle
        translate([0, -carriage_hinge_offset, -height/2+4])
          parallel_joints(16);
		}
		// Screw hole for spectra line tension
	//	translate([0, -3, -11])
	//	 cylinder(r=1.5, h=15, center=true, $fn=24);

		// Screw hole for spectra line tension and bottom slot for tie off
//      translate([8.925, -4.6, -11])
//		 cylinder(r=1.5, h=20, center=true, $fn=24);
//		translate([-8.925, -4.6, 9]) rotate ([0, -90, 0]) {
//		 cube([1.5, 9, 1.5], center=true);
//		}
	 }
  }
}
}

//END CARRIAGE UNIVERSAL JOINTS


union() {

translate([0, 0, 0]) {

carriage();

}

main_carriage();

}
